pub struct ColorBySpeedModule {
pub enabled: bool,
pub gradient: MinMaxGradient,
pub range: Vector2f,
}Expand description
ColorBySpeedModule is a sub class of the Unity engine since version 3.5.0. Exert from Unity’s scripting documentation: Script interface for the ColorBySpeedModule of a Particle System. See Also: ParticleSystem, ParticleSystem.colorBySpeed.
Fields
enabled: boolSpecifies whether the ColorBySpeedModule is enabled or disabled.
gradient: MinMaxGradientrange: Vector2fApply the color gradient between these minimum and maximum speeds.